@@ -28,7 +28,7 @@ class Calendar
    var $lastUpdatedOn;
    var $createdBy;
    var $lastUpdatedBy;
-   var $holidays = array();
+   var $holidays;
    var $events;
    var $allEvents;
    var $unknownAttributes = array();
@@ -44,7 +44,7 @@ class Calendar
      *
      * @param mixed $id The ID of this calendar (optional; ID is auto-
      *                  generated if not given - NOTE that this is never
-     *                  a correct ID for (default) private type calendars!).
+     *                  a correct ID for private type calendars!).
      *                  May be specified as a string or a Property object.
      * @param mixed $sequence The edit sequence ID for this calendar
      *                        May be specified as an int or a Property object.
@@ -182,7 +182,7 @@ class Calendar
 
 
       $sm_cal_prodid = str_replace('###VERSION###', calendar_version(), SM_CAL_PRODID);
-      global $domain, $username, $useDomainInCalID;
+      global $domain, $username;
 
 
 
@@ -197,11 +197,6 @@ class Calendar
       if (empty($o) && empty($w) && empty($r))
          $this->readable_users->setValue(array($username));
 
-      $c = $this->createdBy();
-      if (empty($c))
-      $this->setCreator($username);
-
-
       $p = $this->getProductID();
       if (empty($p))
          $this->prodID->setValue($sm_cal_prodid);
@@ -230,8 +225,7 @@ class Calendar
             // use that
             //
             if (is_object($createdOn) && strtolower(get_class($createdOn)) == 'property')
-               $this->id->setValue('sm_cal_' . gmdate('Ymd\THis\Z', $this->createdOn())
-                                 . ($useDomainInCalID ? '_' . $this->getDomain() : ''));
+               $this->id->setValue('sm_cal_' . gmdate('Ymd\THis\Z', $this->createdOn()) . '_' . $this->getDomain());
 
 
             // otherwise, fudge it
@@ -242,18 +236,15 @@ class Calendar
                //
                if (strlen($uploadFilename) > 6)
                   $uploadFilename = substr($uploadFilename, 0, strlen($uploadFilename) - 5);
-               $this->id->setValue(strtr('sm_uploaded_cal_' . $uploadFilename . '__' . $username 
-                                 . ($useDomainInCalID ? '__' . $domain : ''), 
-                                   '@|_-.:/\ ', '________'));
+               $this->id->setValue(strtr('sm_uploaded_cal_' . $uploadFilename . '__' . $username . '__' . $domain, '@|_-.:/\ ', '________'));
             }
          }
 
 
          else
-//Note: this is not a correct ID for (default) private cals!  caller should not
+//Note: this is not a correct ID for private cals!  caller should not
 //      rely on auto-ID generation for private calendars!
-            $this->id->setValue('sm_cal_' . gmdate('Ymd\THis\Z') 
-                              . ($useDomainInCalID ? '_' . $this->getDomain() : ''));
+            $this->id->setValue('sm_cal_' . gmdate('Ymd\THis\Z') . '_' . $this->getDomain());
       }
       
       $n = $this->getName();
@@ -299,8 +290,6 @@ class Calendar
      * @param int $month The month to be retrieved
      * @param string $user The user for which events are being retrieved
      *
-     * @access private
-     *
      */
    function retrieveEventsForMonth($year, $month, $user)
    {
@@ -350,8 +339,6 @@ class Calendar
      *
      * @param string $user The user for which events are being retrieved
      *
-     * @access private
-     *
      */
    function retrieveAllEvents($user)
    {
@@ -384,8 +371,6 @@ class Calendar
      *
      * @param string $user The user for which events are being retrieved
      *
-     * @access private
-     *
      */
    function retrieveRecurringEvents($user)
    {
@@ -421,8 +406,6 @@ class Calendar
      *
      * @param string $user The user for which holidays are being retrieved
      *
-     * @access private
-     *
      */
    function retrieveHolidays($user)
    {
@@ -453,8 +436,6 @@ class Calendar
      *
      * @return boolean TRUE if calendar source is an external URI, FALSE otherwise
      *
-     * @access public
-     *
      */
    function isExternal()
    {
@@ -470,8 +451,6 @@ class Calendar
      *
      * @param boolean $external TRUE if the source is external, FALSE otherwise
      *
-     * @access public
-     *
      */
    function setExternal($external)
    {
@@ -485,8 +464,6 @@ class Calendar
      *
      * @return string This calendar's internal ID
      *
-     * @access public
-     *
      */
    function getID()
    {
@@ -506,8 +483,6 @@ class Calendar
      *
      * @param string $id The new ID to be assigned to this calendar
      *
-     * @access public
-     *
      */
    function setID($id)
    {
@@ -525,8 +500,6 @@ class Calendar
    /**
      * Increment Sequence Number
      *
-     * @access public
-     *
      */
    function incrementSequence()
    {
@@ -542,8 +515,6 @@ class Calendar
      *                     which should correspond to the calendar type
      *                     constants defined in {@link constants.php}
      *
-     * @access public
-     *
      */
    function setType($type)
    {
@@ -559,8 +530,6 @@ class Calendar
      *                correspond to the calendar type
      *                constants defined in {@link constants.php}
      *
-     * @access public
-     *
      */
    function getCalendarType()
    {
@@ -574,24 +543,9 @@ class Calendar
      *
      * @return string This calendar's name
      *
-     * @access public
-     *
      */
    function getName()
    {
-
-      // need to translate (default) personal calendar name 
-      // here since we can't always count on the correct
-      // language having been used when it was created
-      //
-      global $username, $domain;
-      if ($this->getCalendarType() == SM_CAL_TYPE_PERSONAL 
-       && get_personal_cal_id($username, $domain, TRUE) == $this->getID())
-      {
-         global $username;
-         return sprintf(_("Personal Calendar for %s"), $username);
-      }
-
       return $this->name->getValue();
    }
 
@@ -602,8 +556,6 @@ class Calendar
      *
      * @param string $name The new name to be assigned to this calendar
      *
-     * @access public
-     *
      */
    function setName($name)
    {
@@ -617,8 +569,6 @@ class Calendar
      *
      * @return string This calendar's domain
      *
-     * @access public
-     *
      */
    function getDomain()
    {
@@ -632,8 +582,6 @@ class Calendar
      *
      * @return string The product ID for the product that created this calendar
      *
-     * @access public
-     *
      */
    function getProductID()
    {
@@ -647,8 +595,6 @@ class Calendar
      *
      * @return string This event's creator
      *
-     * @access public
-     *
      */
    function createdBy()
    {
@@ -657,28 +603,11 @@ class Calendar
 
 
 
-   /**
-     * Set Username of User Who Created This Calendar
-     *
-     * @param string $user The name of the user who created this calendar
-     *
-     * @access public
-     *
-     */
-   function setCreator($user)
-   {
-      return $this->createdBy->setValue($user);
-   }
-
-
-
    /**
      * Get Creation Date
      *
      * @return timestamp This calendar's creation date
      *
-     * @access public
-     *
      */
    function createdOn()
    {
@@ -692,8 +621,6 @@ class Calendar
      *
      * @return string This calendar's last editor
      *
-     * @access public
-     *
      */
    function lastUpdatedBy()
    {
@@ -707,8 +634,6 @@ class Calendar
      *
      * @param string $user The name of the user updating this calendar
      *
-     * @access public
-     *
      */
    function setLastUpdator($user)
    {
@@ -722,8 +647,6 @@ class Calendar
      *
      * @return timestamp The date of this calendar's last update
      *
-     * @access public
-     *
      */
    function lastUpdatedOn()
    {
@@ -738,8 +661,6 @@ class Calendar
      * @param string $timestamp The date this calendar was last updated
      *                          (should be a UTC-formatted date/time string)
      *
-     * @access public
-     *
      */
    function setLastUpdateDate($timestamp)
    {
@@ -753,8 +674,6 @@ class Calendar
      *
      * @return array An array listing all calendar owners
      *
-     * @access public
-     *
      */
    function getOwners()
    {
@@ -775,8 +694,6 @@ class Calendar
      * @return array An array listing all users
      *               who have read access to this calendar
      *
-     * @access public
-     *
      */
    function getReadableUsers()
    {
@@ -797,8 +714,6 @@ class Calendar
      * @return array An array listing all users
      *               who have write access to this calendar
      *
-     * @access public
-     *
      */
    function getWriteableUsers()
    {
@@ -818,8 +733,6 @@ class Calendar
      *
      * @return array An array of all unknown attributes
      *
-     * @access public
-     *
      */
    function getUnknownAttributes()
    {
@@ -832,49 +745,19 @@ class Calendar
      * Add a series of new events to this calendar.  Events
      * are merged with those already in the calendar.
      *
-     * Note: can only accomodate up to 1,000,000 events in one 
-     * calendar when $forceAddAll is TRUE.
-     *
      * @param array $newEvents An array of event arrays, keyed 
      *                         by string sindicating event 
      *                         type ("onetime", "recurring", etc)
      * @param string $oldParentCalID The ID of the calendar that
      *                               has owned the events up to now
-     * @param boolean $holdNewEvents If TRUE, will NOT save new events
-     *                               (updated events are ALWAYS saved)
-     *                               to the backend, and will instead 
-     *                               just keep the events in memory 
-     *                               inside of the calendar object for 
-     *                               saving at a later time. (optional; 
-     *                               default = FALSE)
-     * @param boolean $forceAddAll If TRUE, will add all events,
-     *                             even when event IDs conflict
-     *                             (when events would otherwise be
-     *                             synched) (conflicts are avoided 
-     *                             by adding random numbers to event 
-     *                             IDs) (optional; default = FALSE)
-     *
-     * @access public
      *
      */
-   function addEvents($newEvents, $oldParentCalID, 
-                      $holdNewEvents=FALSE, $forceAddAll=FALSE)
+   function addEvents($newEvents, $oldParentCalID)
    {
 
       if (empty($newEvents) || !is_array($newEvents)) return;
 
 
-      if (!isset($this->events) 
-       || !is_array($this->events))
-         $this->events = array();
-      if (!isset($this->events['onetime']) 
-       || !is_array($this->events['onetime']))
-         $this->events['onetime'] = array();
-      if (!isset($this->events['recurring']) 
-       || !is_array($this->events['recurring']))
-         $this->events['recurring'] = array();
-
-
       $allEvents = array();
 //TODO: what about other event types???  todos? holidays?
       if (isset($newEvents['onetime']) && is_array($newEvents['onetime']))
@@ -884,7 +767,7 @@ class Calendar
          $allEvents = array_merge($allEvents, $newEvents['recurring']);
 
 
-      // 
+      // one-time events first
       //
       foreach ($allEvents as $event)
       {
@@ -892,53 +775,16 @@ class Calendar
          // attempt to get same event from backend
          //
          $event2 = get_event($this->getID(), $event->getID());
-         if ($event2 === FALSE) $event2 = $this->getEvent($event->getID());
-
-
-         // if we have a duplicate event ID but are forced
-         // to add it anyway, create unique ID and then add it
-         //
-         if ($forceAddAll) 
-         {
-            sq_mt_randomize();
-            $id = $event->getID();
-            while ($event2 !== FALSE)
-            {
-               $id = $event->getID() . mt_rand(1, 1000000);
-               $event2 = get_event($this->getID(), $id);
-               if ($event2 === FALSE) $event2 = $this->getEvent($id);
-            }
-            $event->setID($id);
-
-         }
-
 
          // add event to this cal if not found
          //
          if ($event2 === FALSE)
          {
-
             $event->removeParentCalendar($oldParentCalID);
             $event->addParentCalendar($this->getID());
 //TODO: see notes below about permissions not getting preserved
-            $event->resetPermissionsToParent(array($this));
-            $event->removeParentCalendar($oldParentCalID);
-
-
-            // save event in correct place in memory
-            // if we are not saving to the backend
-            //
-            if ($holdNewEvents)
-            {
-//TODO: what about other event types???  todos? holidays?
-               if ($event->isRecurring())
-                  $this->events['recurring'][] = $event;
-               else if ($event->isOneTime())
-                  $this->events['onetime'][] = $event;
-            }
-            else
-               create_event($this->getID(), $event);
-
+            $event->resetPermissionsToParent();
+            create_event($this->getID(), $event);
          }
 
 
@@ -955,7 +801,7 @@ class Calendar
 //      check if an upload will somehow munge any perms we may have
 //      had (because it gets uploaded to a temporary new calendar 
 //      that is different from this one)
-            $event->resetPermissionsToParent(array($this));
+            $event->resetPermissionsToParent();
             update_event($this->getID(), $event);
          }
 
@@ -976,8 +822,6 @@ class Calendar
      *               indicating event type ("onetime", 
      *               "recurring", etc)
      *
-     * @access public
-     *
      */
    function getEvents()
    {
@@ -999,12 +843,9 @@ class Calendar
      * @return object An event object if the event was found
      *                in memory in the current object; FALSE otherwise
      *
-     * @access public
-     *
      */
    function getEvent($eventID)
    {
-//TODO: what about other event types???  todos? holidays?
 
       // look amongst one time events 
       //
@@ -1039,8 +880,6 @@ class Calendar
      *             or 0 if the calendars should be
      *             considered to be "equal".
      *
-     * @access public
-     *
      */
    function compareTo($otherCalendar)
    {
@@ -1062,8 +901,6 @@ class Calendar
      * @return array A list of all the events that occur today, sorted
      *               chronologically (array of Event objects)
      *
-     * @access public
-     *
      */
    function getEventsForDay($year, $month, $day, $user)
    {
@@ -1141,8 +978,6 @@ class Calendar
      *                         constants defined in {@link constants.php}
      *                         (optional; default is normal month view mode)
      *
-     * @access public
-     *
      */
    function showMonth($year, $month, $startDay, $user, $viewType=SM_CAL_VIEW_MODE_MONTH)
    {
@@ -1172,8 +1007,6 @@ class Calendar
      * @param int $year The year to be shown
      * @param string $user The user for which events are being displayed
      *
-     * @access public
-     *
      */
    function showYear($year, $user)
    {
@@ -1192,8 +1025,6 @@ class Calendar
      * @param string $user The user for which events are being displayed
      * @param int $startDay The day of the week for first display column
      *
-     * @access public
-     *
      */
    function showAllMonths($year, $user, $startDay)
    {
@@ -1219,8 +1050,6 @@ class Calendar
      *                        FALSE, a limited number of hours are
      *                        displayed per the configuration file.
      *
-     * @access public
-     *
      */
    function showDay($year, $month, $day, $user, $allDay=FALSE)
    {
@@ -1245,8 +1074,6 @@ class Calendar
      * @return array A list of all the holidays that occur today, sorted
      *               chronologically (array of Event objects)
      *
-     * @access public
-     *
      */
    function getHolidaysForDay($year, $month, $day, $user)
    {
@@ -1298,8 +1125,6 @@ class Calendar
      *
      * @param string $user The user to be removed
      *
-     * @access public
-     *
      */
    function remove_user($user)
    {
@@ -1321,8 +1146,6 @@ class Calendar
      *                            which should correspond
      *                            to the calendar access constants
      *                            defined in {@link constants.php}
-     * @access public
-     *
      */
    function add_user($user, $accessLevel)
    {
@@ -1347,8 +1170,6 @@ class Calendar
      *
      * @return boolean TRUE if the user is an owner of this calendar, FALSE otherwise
      *
-     * @access public
-     *
      */
    function isOwner($user)
    {
@@ -1375,8 +1196,6 @@ class Calendar
      *
      * @return boolean TRUE if the user has read access to this calendar, FALSE otherwise
      *
-     * @access public
-     *
      */
    function canRead($user)
    {
@@ -1411,8 +1230,6 @@ class Calendar
      *
      * @return boolean TRUE if the user has write access to this calendar, FALSE otherwise
      *
-     * @access public
-     *
      */
    function canWrite($user)
    {
@@ -1446,8 +1263,6 @@ class Calendar
      *                                  wiped and reset to match
      *                                  their parent calendar.  
      *
-     * @access public
-     *
      */
    function saveEvents($resetPermissions)
    {
@@ -1509,51 +1324,36 @@ class Calendar
      *                                     When not given, no events are 
      *                                     included; only the calendar itself 
      *                                     is returned (optional; default = empty).
-     * @param string $icalLineDelimOverride If given, will be used instead
-     *                                      the RFC-standard CRLF to terminate
-     *                                      iCal lines (optional)
      *
      * @return string The iCal stream representing this calendar
      *
-     * @access public
-     *
      */
-   function getICal($includeExtras=FALSE, $includeEventsForUser='', 
-                    $icalLineDelimOverride='')
+   function getICal($includeExtras=FALSE, $includeEventsForUser='')
    {
 
-      // figure out line delimiter
-      //
-      if (empty($icalLineDelimOverride))
-         $icalLineDelim = ICAL_LINE_DELIM;
-      else
-         $icalLineDelim = $icalLineDelimOverride;
-
-
       $iCalVersion = '2.0';
       $sm_cal_prodid = str_replace('###VERSION###', calendar_version(), SM_CAL_PRODID);
 
 
-      $iCalText = 'BEGIN:VCALENDAR' . $icalLineDelim
-                . 'VERSION:' . $iCalVersion . $icalLineDelim
-                . $this->prodID->getICal($icalLineDelim)
-                . 'CALSCALE:GREGORIAN' . $icalLineDelim
-                . 'METHOD:PUBLISH' . $icalLineDelim
+      $iCalText = 'BEGIN:VCALENDAR' . ICAL_LINE_DELIM
+                . 'VERSION:' . $iCalVersion . ICAL_LINE_DELIM
+                . $this->prodID->getICal()
+                . 'CALSCALE:GREGORIAN' . ICAL_LINE_DELIM
 
                 // make Apple happy
                 //
-                . 'X-WR-CALNAME:' . $this->getName() . $icalLineDelim
-                . 'X-WR-RELCALID:' . $this->id->getValue() . $icalLineDelim;
+                . 'X-WR-CALNAME:' . $this->name->getValue() . ICAL_LINE_DELIM
+                . 'X-WR-RELCALID:' . $this->id->getValue() . ICAL_LINE_DELIM;
 
 
       // only show our own custom ID and name fields 
       // if this calendar was created by this application
       //
       if ($this->getProductID() == $sm_cal_prodid)
-         $iCalText .= $this->id->getICal($icalLineDelim)
+         $iCalText .= $this->id->getICal()
 //LEFT OFF HERE
 //TODO: following property should have language and encoding info! (take care of in constructor??)
-                    . $this->name->getICal($icalLineDelim);
+                    . $this->name->getICal();
 
 
       // unknown attributes are included, since they
@@ -1565,23 +1365,23 @@ class Calendar
          // already printed these
          //
          if ($name != 'X-WR-CALNAME' && $name != 'X-WR-RELCALID')
-            $iCalText .= $attr . $icalLineDelim;
+            $iCalText .= $attr . ICAL_LINE_DELIM;
 
 
       // include all our internal attributes?
       //
       if ($includeExtras)
       {
-         $iCalText .= $this->dom->getICal($icalLineDelim)
-                    . $this->type->getICal($icalLineDelim)
-                    . $this->sequence->getICal($icalLineDelim)
-                    . $this->createdBy->getICal($icalLineDelim)
-                    . $this->createdOn->getICal($icalLineDelim)
-                    . $this->lastUpdatedBy->getICal($icalLineDelim)
-                    . $this->lastUpdatedOn->getICal($icalLineDelim)
-                    . $this->owners->getICal($icalLineDelim) 
-                    . $this->readable_users->getICal($icalLineDelim) 
-                    . $this->writeable_users->getICal($icalLineDelim);
+         $iCalText .= $this->dom->getICal()
+                    . $this->type->getICal()
+                    . $this->sequence->getICal()
+                    . $this->createdBy->getICal()
+                    . $this->createdOn->getICal()
+                    . $this->lastUpdatedBy->getICal()
+                    . $this->lastUpdatedOn->getICal()
+                    . $this->owners->getICal() 
+                    . $this->readable_users->getICal() 
+                    . $this->writeable_users->getICal();
       }
 
 
@@ -1592,12 +1392,12 @@ class Calendar
       {
          $this->retrieveAllEvents($includeEventsForUser);
          foreach ($this->allEvents as $event)
-            $iCalText .= $event->getICal(FALSE, $icalLineDelim);
+            $iCalText .= $event->getICal();
       }
 
 
 
-      $iCalText .= 'END:VCALENDAR' . $icalLineDelim;
+      $iCalText .= 'END:VCALENDAR' . ICAL_LINE_DELIM;
 
 
       // fold lines that are too long
@@ -1630,8 +1430,6 @@ class Calendar
      *
      * @return object A Calendar object representing the given iCal stream.
      *
-     * @access public
-     *
      */
    function getCalendarFromICal($iCalText, $fallbackName='', $uploadFilename='')
    {
@@ -1852,47 +1650,39 @@ class Calendar
 //LEFT OFF HERE um, if this is the only place we call the caching function for external calendar events, will it not be able to cache events outside of this date range?  will it slow considerably if the user views months outside this range? does this help (getting it out of the FORM first)?
          sqgetGlobalVar('year', $year, SQ_FORM);
          if (empty($year))
-            $year = date('Y');
-
+         {
+            $now = time();
+            $dateArray = getdate($now);
+            $year = $dateArray['year'];
+         }
          $cacheDate = mktime(12, 0, 0, 1, 7, $year + 2);
-
-         $newEvents = array();
-         $newEvents['onetime'] = array();
-         $newEvents['recurring'] = array();
+         $cal->holidays = array();
+         $cal->events = array();
+         $cal->events['onetime'] = array();
+         $cal->events['recurring'] = array();
 //TODO.... how do we store Todo items???
-//         $newEvents['todo'] = array();
+//         $cal->events['todo'] = array();
          foreach ($embeddedEvents as $event)
          {
+            // manually add parent ID 
+            // 
+//            $parents = $event->getParentCalendars();
+//            if (empty($parents))
+               $event->addParentCalendar($cal->getID());
+
             if ($event->isOneTime())
-               $newEvents['onetime'][] = $event;
+               $cal->events['onetime'][] = $event;
             else if ($event->isRecurring())
             {
-               $newEvents['recurring'][] = $event;
+               $cal->events['recurring'][] = $event;
+               foreach ($cal->events['recurring'] as $index => $event)
+                  $cal->events['recurring'][$index]->forceEventOccurrenceCache($cacheDate);
             }
 //TODO.... how do we store Todo items???
 //            else if ($event->isTask())
-//               $newEvents['todo'][] = $event;
+//               $cal->events['todo'][] = $event;
          }
 
-         // precache recurring events
-         //
-         foreach (array_keys($newEvents['recurring']) as $index)
-            $newEvents['recurring'][$index]->forceEventOccurrenceCache($cacheDate);
-
-
-         // Add all events to the calendar now.
-         //
-         // Setting the third parameter below to TRUE means
-         // we trust that all events are legitimate and no
-         // duplicates exist; imported calendars that have
-         // those problems should be fixed at the source anyway.
-         // This also fixes problem when importing events w/no
-         // IDs quickly while looping through uploaded iCal file,
-         // timestamps are likely to match, so IDs will overlap,
-         // but the TRUE below fixes that
-         //
-         $cal->addEvents($newEvents, 'xxx', TRUE, TRUE);
-
       }
 
 
