@@ -1026,24 +1026,12 @@ class Property
    /**
      * Get iCal Format Data Stream
      *
-     * @param string $icalLineDelimOverride If given, will be used instead
-     *                                      the RFC-standard CRLF to terminate
-     *                                      iCal lines (optional)
-     *
      * @return string The iCal-formatted representation of this property
      *
      */
-   function getICal($icalLineDelimOverride='')
+   function getICal()
    {
 
-      // figure out line delimiter
-      //
-      if (empty($icalLineDelimOverride)) 
-         $icalLineDelim = ICAL_LINE_DELIM;
-      else
-         $icalLineDelim = $icalLineDelimOverride;
-
-
       // name
       //
       $iCalText = $this->getName();
@@ -1080,13 +1068,6 @@ class Property
       }
 
 
-      // date properties get extra parameter since
-      // default value type would otherwise be date-time
-      //
-      if ($this->getType() == SM_CAL_ICAL_PROPERTY_TYPE_DATE)
-         $iCalText .= ';VALUE=DATE';
-      
-
       // value
       //
       $val = $this->getRawValue();
@@ -1109,7 +1090,7 @@ class Property
 
       // EOL
       //
-      $iCalText .= $icalLineDelim;
+      $iCalText .= ICAL_LINE_DELIM;
 
 
       return $iCalText;
