@@ -22,22 +22,32 @@ include_once(SM_PATH . 'plugins/calendar/interface/helper_month.php');
 
 
 
-global $username, $week_start_day;
-
-
-
 // get calendar...
 //
+global $username, $domain, $week_start_day;
 sqgetGlobalVar('calID', $calID, SQ_FORM);
 $calID = urldecode($calID);
-$calendar = get_calendar($calID);
 
 
 
-// check that user has access rights
+// personal calendar: get ID from backend, then get calendar
 //
-if (!$calendar->canRead($username) && !$calendar->canWrite($username) && !$calendar->isOwner($username))
-   exit;
+if ($calID == 'personal')
+{
+   $calID = get_personal_cal_id($username, $domain);
+   $calendar = get_calendar($calID);
+}
+
+
+// for any other type of calendar, we should check
+// that user has access rights
+//
+else
+{
+   $calendar = get_calendar($calID);
+   if (!$calendar->canRead($username) && !$calendar->canWrite($username) && !$calendar->isOwner($username))
+      exit;
+}
 
 
 
