@@ -82,12 +82,16 @@ function display_calendar_admin_interface($color, $calList)
    textdomain ('calendar');
 
    echo "<br><table align=\"center\" width=\"80%\"><tr><td align=\"left\">" 
-      . _("<b>Shared</b> calendars can be assigned to users with read only or read/write access. To manage user access to your shared calendars, use the \"Users\" button.") 
+      . _("<b>Shared</b>\n"
+      . " calendars can be assigned to users with read only\n"
+      . " or read/write access. To manage user access to your\n"
+      . " shared calendars, use the \"Users\" button.") 
       . "</td></tr><tr><td align=\"left\">"
 
       . "<br>" 
 
-      . _("<b>Public</b> calendars are available to all users in addition to their private personal calendar.") 
+      . _("<b>Public</b> calendars are available to all users\n"
+      . " in addition to their private personal calendar.") 
       . "</td></tr></table><br>\n"
       . "<form action=\"admin_options.php\" method=\"post\">\n"
       . "<table align=\"center\" width=\"80%\" bgcolor=\"" . $color[9] . "\">\n"
@@ -103,8 +107,8 @@ function display_calendar_admin_interface($color, $calList)
       foreach ($sharedList as $calendar)
       {
          echo "<tr><td align=\"center\">\n"
-            . "<input type=\"checkbox\" name=\"delitem[" . $calendar->getID() . "]\" id=\"delitem" . $calendar->getID() . "\" value=\"1\" />\n"
-            . "</td><td align=\"center\"><label for=\"delitem" . $calendar->getID() . "\">" . $calendar->getName() . "</label></td></tr>\n";
+            . "<input type=\"checkbox\" name=\"delitem[" . $calendar->getID() . "]\" value=\"1\" />\n"
+            . "</td><td align=\"center\">" . $calendar->getName() . "</td></tr>\n";
       }
    }
    else
@@ -128,8 +132,8 @@ function display_calendar_admin_interface($color, $calList)
       foreach ($publicList as $calendar)
       {
          echo "<tr><td align=\"center\">\n"
-            . "<input type=\"checkbox\" name=\"delitem[" . $calendar->getID() . "]\" id=\"delitem" . $calendar->getID() . "\" value=\"1\" />\n"
-            . "</td><td align=\"center\"><label for=\"delitem" . $calendar->getID() . "\">" . $calendar->getName() . "</label></td></tr>\n";
+            . "<input type=\"checkbox\" name=\"delitem[" . $calendar->getID() . "]\" value=\"1\" />\n"
+            . "</td><td align=\"center\">" . $calendar->getName() . "</td></tr>\n";
       }
    }
    else
@@ -192,19 +196,26 @@ function display_user_admin_interface($color, $calList)
 
    echo "<table align=\"center\" width=\"80%\"><tr><td><br>\n";
 
-   echo _("<b>To delete one or more users</b> from a calendar, check the box next to each username and click the 'Delete Users' button.")
+   echo _("<b>To delete one or more users</b> from a calendar, check the box next\n"
+        . " to each username and click the 'Delete Users' button.") . "<br><br>\n"
+
+        . _("<b>To add a user</b> to a calendar, type in the username below the\n"
+        . " calendar, choose the user's access level, and click the 'Add User' button.") 
         . "<br><br>\n"
 
-        . _("<b>To add a user</b> to a calendar, type in the username below the calendar, choose the user's access level, and click the 'Add User' button.") 
+        . _("Note that you may use wildcards in user names: * means \"zero\n"
+        . " or more characters\" and ? means \"exactly one alphanumeric\n"
+        . " character\". For example, \"*@mydomain.com\" will give everyone\n"
+        . " in \"mydomain.com\" access to the calendars you assign to that\n"
+        . " username.\n")
         . "<br><br>\n"
 
-        . _("Note that you may use wildcards in user names: * means \"zero or more characters\" and ? means \"exactly one alphanumeric character\". For example, \"*@mydomain.com\" will give everyone in \"mydomain.com\" access to the calendars you assign to that username.\n")
+        . _("<b>To update user access levels</b> for a calendar, adjust the 'Access\n"
+        . " Level' selections, then click the 'Save' button below that calendar.") 
         . "<br><br>\n"
 
-        . _("<b>To update user access levels</b> for a calendar, adjust the 'Access Level' selections, then click the 'Save' button below that calendar.") 
-        . "<br><br>\n"
-
-        . _("Note that only owners of public calendars will have write access to those calendars.\n")
+        . _("Note that only owners of public calendars will have write access\n"
+        . " to those calendars.\n")
 
         . "</td></tr></table>\n";
              
@@ -251,8 +262,8 @@ function display_user_admin_interface($color, $calList)
       {
 
          $encodedUser = str_replace(array(' ', '?', '*'), array('SPACE', 'QUESTION', 'ASTERISK'), $user);
-         echo "<tr><td align=\"center\"><input type=\"checkbox\" name=\"users[" . $encodedUser . "]\" id=\"users" . $encodedUser . "\" /></td>"
-            . "<td align=\"left\"><label for=\"users" . $encodedUser . "\">$user</label></td><td align=\"left\">"
+         echo "<tr><td align=\"center\"><input type=\"checkbox\" name=\"users[" . $encodedUser . "]\" /></td>"
+            . "<td align=\"left\">$user</td><td align=\"left\">"
             . "<select name=\"userPerms[$encodedUser]\">";
 
          if ($calendar->getCalendarType() != SM_CAL_TYPE_PUBLIC)
@@ -324,16 +335,18 @@ function display_holiday_admin_interface($color, $calendar, $holidayList)
    
    echo "<table align=\"center\" width=\"80%\"><tr><td><br>\n";
    
-   echo _("<b>To create a holiday,</b> blah blah and click the 'Blah Blah' button.")
-        . "<br><br>\n"
+   echo _("<b>To create a holiday,</b> blah blah\n"
+        . " and click the 'Blah Blah' button.") . "<br><br>\n"
         
         . _("Note that you must also add the new holiday to your calendar if desired.\n")
         . "<br><br>\n"
 
-        . _("<b>To add a holiday</b> to a calendar, blah blah blah and click the 'Blah Blah' button.")
+        . _("<b>To add a holiday</b> to a calendar, blah blah blah\n"
+        . " and click the 'Blah Blah' button.")
         . "<br><br>\n"
         
-        . _("<b>To remove a holiday</b> from a calendar, blah blah blah, then click the 'Blah' button below that calendar.")
+        . _("<b>To remove a holiday</b> from a calendar, blah blah blah,\n"
+        . " then click the 'Blah' button below that calendar.")
 
         . "</td></tr></table>\n";
 
@@ -391,8 +404,8 @@ this code just stolen from above....
       {
 
          $encodedUser = str_replace(array(' ', '?', '*'), array('SPACE', 'QUESTION', 'ASTERISK'), $user);
-         echo "<tr><td align=\"center\"><input type=\"checkbox\" name=\"users[" . $encodedUser . "]\" id=\"users" . $encodedUser . "\" /></td>"
-            . "<td align=\"left\"><label for=\"users" . $encodedUser . "\">$user</label></td><td align=\"left\">"
+         echo "<tr><td align=\"center\"><input type=\"checkbox\" name=\"users[" . $encodedUser . "]\" /></td>"
+            . "<td align=\"left\">$user</td><td align=\"left\">"
             . "<select name=\"userPerms[$encodedUser]\">";
 
          if ($calendar->getCalendarType() != SM_CAL_TYPE_PUBLIC)
