@@ -33,6 +33,10 @@ function showDayViewHeader($calendar, $year, $month, $day)
    $next_year = date('Y', $next_date );
 
 
+   bindtextdomain ('calendar', SM_PATH . 'locale');
+   textdomain ('calendar');
+
+
    $self = 'day.php';
 
    echo html_tag('table', '', '', 
@@ -54,6 +58,9 @@ function showDayViewHeader($calendar, $year, $month, $day)
       . '</table>';
 
 
+   bindtextdomain ('squirrelmail', SM_PATH . 'locale');
+   textdomain ('squirrelmail');
+
 }
 
 
@@ -79,7 +86,7 @@ function showCalendarDay(&$calendar, $year, $month, $day, $user, $allDay=FALSE)
 
    global $color, $calendar_theme, $day_view_start_time, $day_view_end_time,
           $username, $max_displayable_early_morn_late_nite_event_names,
-          $hour_format, $day_view_short_time, $highlight_threshold,
+          $twentyfourHourTime, $day_view_short_time, $highlight_threshold,
           $day_view_show_hourly_add_buttons;
 
 
@@ -446,13 +453,13 @@ function showCalendarDay(&$calendar, $year, $month, $day, $user, $allDay=FALSE)
 
       if ($outputIndex % 4 == 0)
       {
-         $timeString = ($hour_format == SMPREF_TIME_24HR ? $timeIndex 
+         $timeString = ($twentyfourHourTime ? $timeIndex 
                         : ($timeIndex < 13 ? ($timeIndex == 0 ? '12' : $timeIndex) 
                            : $timeIndex - 12)) 
                      . ($day_view_short_time ? '' : ':00');
 
          echo html_tag('td', '<small>' 
-            . ($hour_format == SMPREF_TIME_24HR ? $timeString 
+            . ($twentyfourHourTime ? $timeString 
                : ($timeIndex < 12 ? sprintf(_("%sam"), $timeString) 
                   : sprintf(_("%spm"), $timeString)))
             . '</small>'
@@ -674,21 +681,9 @@ function showDayViewFooter($calendar, $year, $month, $day)
       . "<select name=\"year\">\n"
       . select_option_year($year)
       . "          </select>\n"
-      . "          <select name=\"month\">\n";
-
-   // select_option_month() needs to be called when in SM core locale
-   // 
-   bindtextdomain ('squirrelmail', SM_PATH . 'locale');
-   textdomain ('squirrelmail');
-
-   echo select_option_month($month);
-
-   // switch back to our locale
-   //
-   bindtextdomain ('calendar', SM_PATH . 'locale');
-   textdomain ('calendar');
-
-   echo "          </select>\n"
+      . "          <select name=\"month\">\n"
+      . select_option_month($month)
+      . "          </select>\n"
       . "          <select name=\"day\">\n"
       . select_option_day($day)
       . "          </select>\n"
@@ -717,7 +712,7 @@ function showDayViewFooter($calendar, $year, $month, $day)
 
    echo "<option value=\"day.php?year=$year&month=$month&day=$day&calID=personal\""
       . ($calendar->getID() == get_personal_cal_id($username, $domain) ? ' SELECTED' : '')
-      . '>' . _("Personal") . "</option>\n"
+      . ">Personal</option>\n"
       . "          </select>\n"
       . '          <input type="button" value="' . _("Go") . '" onClick="' 
       . 'for (i=0;i<document.calswitch.calselect.length;i++){ ' 
