@@ -31,7 +31,7 @@ function display_event_edit_interface($color, $year, $month, $day, $hour, $minut
 {
 
    global $editor_size, $day_view_start_time, $max_event_name_length, 
-          $calendar_theme, $hour_format;
+          $calendar_theme, $twentyfourHourTime;
 //LEFT OFF HERE -- is this a config file thing?  or what? (is important to synch with DB backend)
 $max_event_name_length = 100;
 
@@ -213,21 +213,9 @@ $reminderMinutes = FALSE;
       . select_option_year($year)
       . "      </select>\n"
 //      . "      &nbsp;\n"
-      . "      <select name=\"startMonth\">\n";
-
-   // select_option_month() needs to be called when in SM core locale
-   // 
-   bindtextdomain ('squirrelmail', SM_PATH . 'locale');
-   textdomain ('squirrelmail');
-
-   echo select_option_month($month);
-
-   // switch back to our locale
-   //
-   bindtextdomain ('calendar', SM_PATH . 'locale');
-   textdomain ('calendar');
-
-   echo "      </select>\n"
+      . "      <select name=\"startMonth\">\n"
+      . select_option_month($month)
+      . "      </select>\n"
 //      . "      &nbsp;\n"
       . "      <select name=\"startDay\">\n"
       . select_option_day($day)
@@ -263,21 +251,9 @@ $reminderMinutes = FALSE;
       . select_option_year($endYear)
       . "      </select>\n"
 //      . "      &nbsp;\n"
-      . "      <select name=\"endMonth\">\n";
-
-   // select_option_month() needs to be called when in SM core locale
-   // 
-   bindtextdomain ('squirrelmail', SM_PATH . 'locale');
-   textdomain ('squirrelmail');
-
-   echo select_option_month($endMonth);
-
-   // switch back to our locale
-   //
-   bindtextdomain ('calendar', SM_PATH . 'locale');
-   textdomain ('calendar');
-
-   echo "      </select>\n"
+      . "      <select name=\"endMonth\">\n"
+      . select_option_month($endMonth)
+      . "      </select>\n"
 //      . "      &nbsp;\n"
       . "      <select name=\"endDay\">\n"
       . select_option_day($endDay)
@@ -384,21 +360,9 @@ $reminderMinutes = FALSE;
       . select_option_year($endRecurrenceYear)
       . "      </select>\n"
 //      . "      &nbsp;\n"
-      . "      <select name=\"endRecurrenceMonth\">\n";
-
-   // select_option_month() needs to be called when in SM core locale
-   // 
-   bindtextdomain ('squirrelmail', SM_PATH . 'locale');
-   textdomain ('squirrelmail');
-
-   echo select_option_month($endRecurrenceMonth);
-
-   // switch back to our locale
-   //
-   bindtextdomain ('calendar', SM_PATH . 'locale');
-   textdomain ('calendar');
-
-   echo "      </select>\n"
+      . "      <select name=\"endRecurrenceMonth\">\n"
+      . select_option_month($endRecurrenceMonth)
+      . "      </select>\n"
 //      . "      &nbsp;\n"
       . "      <select name=\"endRecurrenceDay\">\n"
       . select_option_day($endRecurrenceDay)
@@ -480,11 +444,7 @@ $reminderMinutes = FALSE;
         "<input type=\"submit\" name=\"submitevent\" value=\"" 
       . $submitButtonText . "\" />\n" ,
         'center', $color[4], 'colspan="2"' ) 
-      . html_tag('td',
-      ($calAction == SM_CAL_EVENT_ACTION_UPDATE
-      ? '<input type="submit" name="deleteevent" value="'
-      . _("Delete Event") . '"/>' : '')
-      , '', $color[4]) . '</td>'
+      . html_tag('td', '', '', $color[4]) . '</td>'
       . '</tr>';
 
 
@@ -501,23 +461,10 @@ $reminderMinutes = FALSE;
          $lastUpdateDate = $event->createdOn();
       $creator = $event->createdBy();
 
-
-      // switch back to SM text domain for date_intl()
-      //
-      bindtextdomain ('squirrelmail', SM_PATH . 'locale');
-      textdomain ('squirrelmail');
-
-      $updateDt = date_intl('M d, Y ' . ($hour_format == SMPREF_TIME_24HR ? 'H:i' : 'g:ia'), $lastUpdateDate);
-      $createDt = date_intl('M d, Y ' . ($hour_format == SMPREF_TIME_24HR ? 'H:i' : 'g:ia'), $event->createdOn());
-
-      bindtextdomain ('calendar', SM_PATH . 'locale');
-      textdomain ('calendar');
-
-
       echo html_tag('tr') 
          . html_tag('td', _("Last Updated:"), 'right', $color[4], 'colspan="2"') . "\n" 
          . html_tag('td', '', 'left', $color[4])
-         . $updateDt
+         . date_intl('M d, Y ' . ($twentyfourHourTime ? 'H:i' : 'g:ia'), $lastUpdateDate)
          . (!empty($lastUpdator) ? ' [' . $lastUpdator . ']' : '')
          . "      </td></tr>\n"
 
@@ -527,7 +474,7 @@ $reminderMinutes = FALSE;
          . html_tag('tr') 
          . html_tag('td', _("Created:"), 'right', $color[4], 'colspan="2"') . "\n" 
          . html_tag('td', '', 'left', $color[4])
-         . $createDt
+         . date_intl('M d, Y ' . ($twentyfourHourTime ? 'H:i' : 'g:ia'), $event->createdOn())
          . (!empty($creator) ? ' [' . $creator . ']' : '')
          . "      </td></tr>\n";
 
@@ -565,7 +512,7 @@ function display_event_display_interface($color, $year, $month, $day, $calendarI
 {
 
    global $calendar_theme, $RECURRENCE_TYPES, $EVENT_PRIORITIES,
-          $hour_format;
+          $twentyfourHourTime;
 
 
    bindtextdomain ('calendar', SM_PATH . 'locale');
@@ -664,17 +611,6 @@ $reminderMinutes = FALSE;
    $creator = $event->createdBy();
 
 
-   // switch back to SM text domain for date_intl()
-   //
-   bindtextdomain ('squirrelmail', SM_PATH . 'locale');
-   textdomain ('squirrelmail');
-
-   $updateDt = date_intl('M d, Y ' . ($hour_format == SMPREF_TIME_24HR ? 'H:i' : 'g:ia'), $lastUpdateDate); 
-   $createDt = date_intl('M d, Y ' . ($hour_format == SMPREF_TIME_24HR ? 'H:i' : 'g:ia'), $event->createdOn());
-
-   bindtextdomain ('calendar', SM_PATH . 'locale');
-   textdomain ('calendar');
-
 
    // display message if given
    //
@@ -773,7 +709,7 @@ $reminderMinutes = FALSE;
       . html_tag('tr')
       . html_tag('td', _("Last Updated:"), 'right', $color[4], 'colspan="2"') . "\n"
       . html_tag('td', '', 'left', $color[4])
-      . $updateDt
+      . date_intl('M d, Y ' . ($twentyfourHourTime ? 'H:i' : 'g:ia'), $lastUpdateDate) 
       . (!empty($lastUpdator) ? ' [' . $lastUpdator . ']' : '')
       . "      </td></tr>\n"
 
@@ -783,7 +719,7 @@ $reminderMinutes = FALSE;
       . html_tag('tr')
       . html_tag('td', _("Created:"), 'right', $color[4], 'colspan="2"') . "\n"
       . html_tag('td', '', 'left', $color[4])
-      . $createDt
+      . date_intl('M d, Y ' . ($twentyfourHourTime ? 'H:i' : 'g:ia'), $event->createdOn())
       . (!empty($creator) ? ' [' . $creator . ']' : '')
       . "      </td></tr>\n"
 
