@@ -22,19 +22,14 @@ function squirrelmail_plugin_init_calendar()
 
    $squirrelmail_plugin_hooks['menuline']['calendar']               = 'cal_menu_link';
    $squirrelmail_plugin_hooks['optpage_register_block']['calendar'] = 'cal_options_block';
+   $squirrelmail_plugin_hooks['loading_prefs']['calendar']          = 'cal_load_prefs';
    $squirrelmail_plugin_hooks['generic_header']['calendar']         = 'small_calendar_style';
    $squirrelmail_plugin_hooks['left_main_after']['calendar']        = 'render_small_calendar';
 
-   // caused chicken-and-egg problems with i18n'd strings in constants file
-   // (that is needed by config file)
-   //
-   //$squirrelmail_plugin_hooks['loading_prefs']['calendar']          = 'cal_load_prefs';
-
 }
 
 
 
-/** @ignore */
 if (!defined('SM_PATH'))
    define('SM_PATH', '../');
 
@@ -47,7 +42,7 @@ if (!defined('SM_PATH'))
 function calendar_version() 
 {
 
-   return '2.0.1';
+   return '2.0';
 
 }
 
@@ -89,7 +84,7 @@ function cal_options_block()
 function cal_load_prefs() 
 {
 
-   include_once(SM_PATH . 'plugins/calendar/load_prefs.php');
+   include_once(SM_PATH . 'plugins/calendar/functions.php');
    cal_load_prefs_do();
 
 }
