@@ -22,27 +22,41 @@ include_once(SM_PATH . 'plugins/calendar/interface/calendar.php');
 
 
 
-global $username, $color, $week_start_day;
-
-
-
 // get calendar...
 //
+global $username, $domain, $color, $week_start_day;
 sqgetGlobalVar('calID', $calID, SQ_FORM);
 $calID = urldecode($calID);
-$calendar = get_calendar($calID);
 
 
 
-// check that user has access rights
+// personal calendar: get ID from backend, then get calendar
 //
-if (!$calendar->canRead($username) && !$calendar->canWrite($username) && !$calendar->isOwner($username))
-   exit;
+if ($calID == 'personal') 
+{
+   $calID = get_personal_cal_id($username, $domain);
+   $calendar = get_calendar($calID);
+}
+
+
+// for any other type of calendar, we should check 
+// that user has access rights 
+// 
+else
+{
+   $calendar = get_calendar($calID);
+   if (!$calendar->canRead($username) && !$calendar->canWrite($username) && !$calendar->isOwner($username))
+      exit;
+}
 
 
 
 sqgetGlobalVar('year', $year, SQ_FORM);
-list($todaysYear, $todaysMonth, $todaysDay) = explode('-', date('Y-n-j'));
+$now = time();
+$dateArray = getdate($now);
+$todaysYear = $dateArray['year'];
+$todaysMonth = $dateArray['mon'];
+$todaysDay = $dateArray['mday'];
 $month = $todaysMonth;
 $day = $todaysDay;
 
